DecisionDisplay

Nonprecedential Decisions Issued 6/1/2014 TO 9/1/2014
xxx
Issued Date | Appellant | Agency
Aug 29, 2014 | Shelli Finch | Department of Veterans Affairs
Aug 29, 2014 | Tonia J. Bibby | Department of Agriculture
Aug 29, 2014 | Rita Easton | Department of the Treasury
Aug 29, 2014 | Tracy A. May | Department of the Air Force
Aug 29, 2014 | Calvin W. Scott | Office of Personnel Management
Aug 28, 2014 | Dana R. Wallace | Office of Personnel Management
Aug 28, 2014 | Donald L. Wencewicz | Department of Transportation
Aug 28, 2014 | Renata M. Lachiewicz | Department of Homeland Security
Aug 28, 2014 | Ann Marie Valinoti-Carcione | Office of Personnel Management
Aug 28, 2014 | William B. Jolley | Department of Justice
Aug 28, 2014 | Susan E. Williams | Department of the Treasury
Aug 28, 2014 | Kenneth Shaw | Department of Veterans Affairs
Aug 28, 2014 | Donna Jo Kruer | Department of Commerce
Aug 28, 2014 | Kirk P. Ponder | Department of the Air Force
Aug 27, 2014 | Hakeem Mustafia Muhammad | Department of the Army
Aug 27, 2014 | Avram E. Glick | Department of the Navy
Aug 27, 2014 | Charles Edwards | Department of the Navy
Aug 27, 2014 | Diane McAuley | Office of Personnel Management
Aug 27, 2014 | Gregory Brownfield | Department of Homeland Security
Aug 27, 2014 | Paul Menard | Department of the Interior
Aug 26, 2014 | DeGerald R. Wilson | Department of State
Aug 26, 2014 | Earnest Howard | Department of the Army
Aug 26, 2014 | DeGerald R. Wilson | Department of Education
Aug 26, 2014 | Joseph J. Rastovski | Office of Personnel Management
Aug 26, 2014 | Anthony Sahadeo | Department of the Navy
Aug 25, 2014 | Janis K. Waters | Department of Transportation
Aug 25, 2014 | Jacqueline R. Manuel | United States Postal Service
Aug 25, 2014 | Steven J. Launer | Department of the Air Force
Aug 25, 2014 | Anthony S. Huntley | United States Postal Service
Aug 25, 2014 | Rosie Y. Camacho | Department of the Army
Aug 22, 2014 | John Edward Ruffin, Jr | Department of Justice
Aug 22, 2014 | David Dean | Office of Personnel Management
Aug 22, 2014 | Oliver L. Baines | Department of Veterans Affairs
Aug 22, 2014 | Maria Theresa Boucher | United States Postal Service
Aug 21, 2014 | Brian Dickson | United States Postal Service
Aug 21, 2014 | James F. Gibson | Department of Transportation
Aug 21, 2014 | Trisha L. Gordon | National Aeronautics and Space Admin
Aug 21, 2014 | Gary S. Schnell | Department of the Army
Aug 21, 2014 | Travis E. Wilkes | Department of Veterans Affairs
Aug 21, 2014 | Stephanie L. Stewart | Department of Agriculture
Aug 21, 2014 | Dennis McGaughy | Office of Personnel Management
Aug 21, 2014 | David Kinglee | United States Postal Service
Aug 21, 2014 | Rodney Howerton | Department of Defense
Aug 21, 2014 | Rosalind Davis | Social Security Administration
Aug 20, 2014 | Illya Erwin | Department of the Army
Aug 20, 2014 | Bonita J. King | United States Postal Service
Aug 20, 2014 | Marshann Terwilliger | Office of Personnel Management
Aug 20, 2014 | Special Counsel ex rel. Karla Saunders | Small Business Administration
Aug 20, 2014 | Special Counsel ex rel. Judy Kachanes | Department of Agriculture
Aug 20, 2014 | Hazel Elizabeth Scott | Office of Personnel Management
Aug 20, 2014 | Anacleto C. Baldueza | Office of Personnel Management
Aug 20, 2014 | Priscilla A. Eberhardt | United States Postal Service
Aug 19, 2014 | Robin R. McFarland | Department of Health and Human Services
Aug 19, 2014 | Pushpa Bisarya | Department of Health and Human Services
Aug 19, 2014 | Nydia Y. Pacheco | Department of Defense
Aug 19, 2014 | David J. Lachance | Department of the Interior
Aug 19, 2014 | Andrew Welhouse | Department of Agriculture
Aug 19, 2014 | William R. Kelly | Department of Commerce
Aug 19, 2014 | Patricia Wolfe | Office of Personnel Management
Aug 19, 2014 | Lisa Marie Butler | Department of the Treasury
Aug 19, 2014 | Sidney Nelson, Jr. | United States Postal Service
Aug 19, 2014 | Karen A. Wilson | United States Postal Service
Aug 19, 2014 | John G. Willis | Social Security Administration
Aug 19, 2014 | Craig Kenneth Spry | Department of Labor
Aug 19, 2014 | Lyniece M. Fuller | Department of Veterans Affairs
Aug 18, 2014 | Jodi E. Silberman | Department of Labor
Aug 18, 2014 | Kerby C. Phillips | Department of the Interior
Aug 18, 2014 | Rhoderick Dwight Hall | United States Postal Service
Aug 18, 2014 | Joan Ryan | Department of Homeland Security
Aug 18, 2014 | Joan Ryan | Department of Homeland Security
Aug 18, 2014 | Ann Marie Duncan | Department of Homeland Security
Aug 18, 2014 | Robert Alan Helfman | Office of Personnel Management
Aug 18, 2014 | Leslie J. Fejfar | United States Postal Service
Aug 18, 2014 | Leslie J. Fejfar | United States Postal Service
Aug 18, 2014 | Charles N. Nordan | Department of the Army
Aug 15, 2014 | Michael E. Phillips | Department of Agriculture
Aug 15, 2014 | Donna K. Sharlofsky | Office of Personnel Management
Aug 15, 2014 | Nathan Bryant, Sr. | Department of Defense
Aug 15, 2014 | Teresa A. Carlstrom | United States Postal Service
Aug 15, 2014 | Laurence M. Fedora | United States Postal Service
Aug 15, 2014 | Keyona R. Harris | Department of Veterans Affairs
Aug 15, 2014 | Christine L. Seed | Department of Energy
Aug 15, 2014 | Ya F. Wang | Department of the Army
Aug 15, 2014 | Christopher L. Elder | Department of the Air Force
Aug 15, 2014 | Otis Miller, Jr. | Department of the Navy
Aug 15, 2014 | Carla Jean Nelson | National Council on Disability
Aug 15, 2014 | Pamela D. Tucker | Department of Veterans Affairs
Aug 15, 2014 | Annette Davis | Department of the Interior
Aug 15, 2014 | Sidney Nelson, Jr. | Office of Personnel Management
Aug 15, 2014 | Blanca Tovias | Department of Transportation
Aug 15, 2014 | Leo Crawford | Office of Personnel Management
Aug 15, 2014 | Mark Steven Cook | Department of Agriculture
Aug 15, 2014 | Terrol M. Prather | Department of the Army
Aug 14, 2014 | Tysha S. Holmes | Department of the Army
Aug 14, 2014 | Matthew John Hayduk | Department of the Army
Aug 14, 2014 | Jay Stanich | United States Postal Service
Aug 14, 2014 | Ayoub Tartir | Department of Agriculture
Aug 14, 2014 | Steven C. Collins, II | Office of Personnel Management
Aug 14, 2014 | Tami L. Williams | Department of the Air Force
Aug 14, 2014 | Jerry L. Bourlet | Office of Personnel Management
Aug 14, 2014 | LaVivian Y. Carey | Department of Veterans Affairs
Aug 14, 2014 | National Association of Government Inspectors, Unit 1 | OPM & Department of the Navy
Aug 13, 2014 | Arthur Llorens | Department of the Air Force
Aug 13, 2014 | Patrick Tangye MBI | Department of Homeland Security
Aug 13, 2014 | Daniel A. Thibeault | United States Postal Service
Aug 13, 2014 | Larry L. Price | Department of Housing and Urban Development
Aug 13, 2014 | Derek J. Farquhar | Department of Veterans Affairs
Aug 12, 2014 | Reynaldo Collins Holder | Department of Defense
Aug 12, 2014 | Thomas J. Luchay | Department of the Navy
Aug 12, 2014 | Rodney M. Walls | United States Postal Service
Aug 12, 2014 | Allen Cammy-El | Department of Veterans Affairs
Aug 12, 2014 | Gary Smith | Department of the Air Force
Aug 12, 2014 | David C. Thomas | Department of the Army
Aug 12, 2014 | Adrienne Curry | Department of Veterans Affairs
Aug 12, 2014 | Steven Michael Noppenberger | United States Postal Service
Aug 12, 2014 | Cynthia Ann Rickis | Department of Veterans Affairs
Aug 11, 2014 | Terrance Miguel Peterson | Department of Veterans Affairs
Aug 11, 2014 | Johnny L. Milligan | Government of the District of Columbia
Aug 08, 2014 | Colleen F. Clay | Corporation for National and Community Service
Aug 08, 2014 | Jacqueline L. Dumpson | Social Security Administration
Aug 07, 2014 | Nataki Damali MacMurray | Ofc of National Drug Control Policy
Aug 07, 2014 | Hays C. Hussey | Department of Agriculture
Aug 07, 2014 | Alphonso Bernard Clark | Social Security Administration
Aug 06, 2014 | Margaret M. Bradley | Office of Personnel Management
Aug 06, 2014 | Anthony W. Perry | Department of Commerce
Aug 06, 2014 | Joe Cox | Department of Homeland Security
Aug 06, 2014 | Dean M. Finch | United States Postal Service
Aug 06, 2014 | David L. Taylor, Sr. | United States Postal Service
Aug 06, 2014 | Tracy A. Jenson | Office of Personnel Management
Aug 06, 2014 | Charisse L. Newson | Department of Labor
Aug 05, 2014 | Diane King | Department of Veterans Affairs
Aug 05, 2014 | Diane King | Department of Veterans Affairs
Aug 05, 2014 | Diane King | Department of the Army
Aug 05, 2014 | Travis Lamont Sutton | Department of Veterans Affairs
Aug 05, 2014 | Samuel Herrera-Diaz | Office of Personnel Management
Aug 05, 2014 | Anthony Z. Alderete | Department of Defense
Aug 05, 2014 | Rosemary Jenkins | United States Postal Service
Aug 05, 2014 | Richard Zakosky | Department of Veterans Affairs
Aug 05, 2014 | Carol L. Brink-Meissner | Office of Personnel Management
Aug 05, 2014 | Corazon McDonald | Department of the Army
Aug 05, 2014 | Carter D. Mansfield | Department of Justice
Aug 04, 2014 | Kashif A. Rasheed | Department of Transportation
Aug 04, 2014 | Darlene Constance Harris | United States Postal Service
Aug 04, 2014 | Michele Gilchrist | United States Postal Service
Aug 04, 2014 | Frederick B. Mize | Office of Personnel Management
Aug 04, 2014 | Julie A. Madarang | Office of Personnel Management
Aug 04, 2014 | Eric A. England | Department of the Army
Aug 04, 2014 | Meiling Chin | Department of Labor
Aug 04, 2014 | Clifford W. Jones, Sr. | Department of Health and Human Services
Aug 04, 2014 | Darryle Bigelow, Sr | United States Postal Service
< >